@@ -20,9 +20,17 @@
 #ifndef ICONBAR_H
 #define ICONBAR_H
 
+#if defined(USE_HILDON) && (MAEMO_VERSION_MAJOR == 5)
+#define FINGER_UI
+#endif
+
 typedef struct iconbar_s {
   GtkWidget *toolbar;
 
+#ifdef FINGER_UI
+  GtkWidget *menu;
+#endif
+
   GtkWidget *info;
   GtkWidget *trash;
   GtkWidget *node_add;
