@@ -68,21 +68,21 @@ settings_t *settings_load(void) {
 
   /* ------ set useful defaults ------- */
 
-#ifdef USE_HILDON
-  char *p;
-  settings->base_path = strdup(BASE_DIR);
-#else
   char *p = getenv("HOME");
   g_assert(p);
 
-  /* build image path in home directory */
-  settings->base_path =
-    malloc(strlen(p)+strlen(BASE_DIR)+2);
-  strcpy(settings->base_path, p);
-  if(settings->base_path[strlen(settings->base_path)-1] != '/')
-    strcat(settings->base_path, "/");
-  strcat(settings->base_path, BASE_DIR);
-#endif
+  if (*BASE_DIR == '/')  /* absolute path */
+    settings->base_path = strdup(BASE_DIR);
+  else {
+    /* build image path in home directory */
+    settings->base_path =
+      malloc(strlen(p)+strlen(BASE_DIR)+2);
+    strcpy(settings->base_path, p);
+    if(settings->base_path[strlen(settings->base_path)-1] != '/')
+      strcat(settings->base_path, "/");
+    strcat(settings->base_path, BASE_DIR);
+  }
+  fprintf(stderr, "base_path = %s\n", settings->base_path);
 
   /* ------------- setup download defaults -------------------- */
   settings->server = strdup("http://api.openstreetmap.org/api/0.6");
